/*
 * This file is part of the syndication library.
 *
 * Copyright (C) 2006 Frank Osterfeld <osterfeld@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *
 */

#ifndef SYNDICATION_SYNDICATION_H
#define SYNDICATION_SYNDICATION_H

#include <syndication/specificdocument.h>
#include <syndication/abstractparser.h>
#include <syndication/category.h>
#include <syndication/constants.h>
#include <syndication/dataretriever.h>
#include <syndication/documentsource.h>
#include <syndication/documentvisitor.h>
#include <syndication/elementwrapper.h>
#include <syndication/enclosure.h>
#include <syndication/feed.h>
#include <syndication/global.h>
#include <syndication/image.h>
#include <syndication/item.h>
#include <syndication/loader.h>
#include <syndication/mapper.h>
#include <syndication/parsercollection.h>
#include <syndication/person.h>
#include <syndication/specificitem.h>
#include <syndication/specificitemvisitor.h>
#include <syndication/tools.h>

/**
 * TODO
 */
namespace Syndication {}

#endif // SYNDICATION_SYNDICATION_H
